@@ -22,6 +22,9 @@
 
 char *polari_util_get_basenick (const char *nick);
 
+gboolean polari_util_match_nick (const char *text,
+		                 const char *nick);
+
 gboolean polari_util_match_identify_message (const char  *message,
                                              char       **command,
                                              char       **username,
