@@ -55,7 +55,7 @@ var NetworksManager = class {
     }
 
     getAccountIsPredefined(account) {
-        return account && this._networksById.get(account.service) != null;
+        return account && this._networksById.has(account.service);
     }
 
     getNetworkName(id) {
@@ -65,7 +65,7 @@ var NetworksManager = class {
     getNetworkIsFavorite(id) {
         let network = this._lookupNetwork(id);
 
-        if (network.hasOwnProperty('favorite'))
+        if (Object.prototype.hasOwnProperty.call(network, 'favorite'))
             return network['favorite'];
 
         return false;
@@ -105,7 +105,7 @@ var NetworksManager = class {
 
     findByServer(server) {
         let network = this._networks.find(n => {
-            return n.servers.some(s => s.address == server);
+            return n.servers.some(s => s.address === server);
         });
         return network ? network.id : null;
     }
